@@ -8,15 +8,15 @@ test_that("e_band plot has the good data structure and type", {
   df <- data.frame(
     x = 1:5,
     y = round(runif(5, 5, 10), 6)
-  ) %>%
+  ) |>
     dplyr::mutate(
       lwr = round(y - runif(5, 1, 3), 6),
       upr = y + round(runif(5, 2, 4), 6)
     )
 
-  plot <- df %>%
-    e_charts(x) %>%
-    e_line(y) %>%
+  plot <- df |>
+    e_charts(x) |>
+    e_line(y) |>
     e_band(lwr, upr)
 
   expect_s3_class(plot, "echarts4r")
@@ -40,8 +40,8 @@ test_that("e_band plot has the good data structure and type", {
 
 test_that("e_band2 plot has good data structure and type", {
   df <- data.frame(x = seq(3), y = c(1, 3, 9), w = c(3, 4, 3))
-  plot <- df %>%
-    e_charts(x) %>%
+  plot <- df |>
+    e_charts(x) |>
     e_band2(y, w)
 
   expect_s3_class(plot, "echarts4r")
@@ -58,10 +58,10 @@ test_that("e_band2 plot has good data structure and type", {
 })
 
 test_that("e_correlations plot has the good data structure and type", {
-  plot <- cor(mtcars[6:9, 1:3]) %>%
-    round(7) %>%
-    e_charts() %>%
-    e_correlations(order = "hclust") %>%
+  plot <- cor(mtcars[6:9, 1:3]) |>
+    round(7) |>
+    e_charts() |>
+    e_correlations(order = "hclust") |>
     e_tooltip()
 
   expect_s3_class(plot, "echarts4r")
@@ -95,9 +95,9 @@ test_that("e_error_bar plot has the good data structure and type", {
     lower = c(0.8, 4.3)
   )
 
-  plot <- df %>%
-    e_charts(x) %>%
-    e_bar(y) %>%
+  plot <- df |>
+    e_charts(x) |>
+    e_bar(y) |>
     e_error_bar(lower, upper)
 
   expect_s3_class(plot, "echarts4r")
@@ -136,9 +136,9 @@ test_that("e_boxplot plot has the good data structure and type", {
     )
   )
 
-  plot <- df %>%
-    group_by(grp) %>%
-    e_charts() %>%
+  plot <- df |>
+    group_by(grp) |>
+    e_charts() |>
     e_boxplot(x)
 
   expect_s3_class(plot, "echarts4r")
@@ -176,9 +176,9 @@ test_that("e_histogram plot has the good data structure and type", {
     y = rnorm(10, 20, 12)
   )
 
-  plot <- df %>%
-    e_charts() %>%
-    e_histogram(y) %>%
+  plot <- df |>
+    e_charts() |>
+    e_histogram(y) |>
     e_tooltip()
 
   expect_s3_class(plot, "echarts4r")
@@ -211,16 +211,16 @@ test_that("e_density plot has the good data structure and type", {
     y = rnorm(10, 20, 12)
   )
 
-  plot <- df %>%
-    e_charts() %>%
-    e_histogram(y) %>%
+  plot <- df |>
+    e_charts() |>
+    e_histogram(y) |>
     e_density(
       y,
       name = "density",
       areaStyle = list(opacity = .4),
       smooth = TRUE,
       y_index = 1
-    ) %>%
+    ) |>
     e_tooltip()
 
   expect_s3_class(plot, "echarts4r")
@@ -246,11 +246,11 @@ test_that("e_density plot has the good data structure and type", {
 
 
 test_that("e_lm plot has the good data structure and type", {
-  plot <- iris[c(1:3, 101:103), ] %>%
-    group_by(Species) %>%
-    e_charts(Sepal.Length) %>%
-    e_line(Sepal.Width) %>%
-    e_lm(Sepal.Width ~ Sepal.Length) %>%
+  plot <- iris[c(1:3, 101:103), ] |>
+    group_by(Species) |>
+    e_charts(Sepal.Length) |>
+    e_line(Sepal.Width) |>
+    e_lm(Sepal.Width ~ Sepal.Length) |>
     e_x_axis(min = 4)
 
   expect_s3_class(plot, "echarts4r")
@@ -273,9 +273,9 @@ test_that("e_lm plot has the good data structure and type", {
 
 
 test_that("e_loess plot has the good data structure and type", {
-  plot <- mtcars[1:7, ] %>%
-    e_charts(disp) %>%
-    e_scatter(mpg, qsec) %>%
+  plot <- mtcars[1:7, ] |>
+    e_charts(disp) |>
+    e_scatter(mpg, qsec) |>
     e_loess(mpg ~ disp)
 
   expect_s3_class(plot, "echarts4r")
